<!-- warning: Please don't edit this file. It was automatically generated. -->

# winui3-Microsoft.UI

Windows Runtime (WinRT) APIs for for the `winui3-Microsoft.UI` namespace.

This package provides the `winui3.microsoft.ui` module.
